DeeplinklyLinkOptions class

Constructors

DeeplinklyLinkOptions({required String channel, required String feature, List<String>? tags})
const

Properties

channel String
final
feature String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<String>?
Free-form labels attached to the generated link.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited